#!/bin/sh
# Copyright (c) 2007 Jeremie Le Hen <jeremie@le-hen.org>.  All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY STEPHAN SCHMIEDER AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL STEPHAN SCHMIEDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

usage() {
	name=`basename $0`
	cat >&2 <<EOF
Usage: $name [-D <destdir>] [-h] [-L <path>] [-u]
Options:
    -D	Install files to <destdir>.
    -h	Show this help message.
    -L	Create symlinks to installed files in <path>.
	This is especially useful when one does not want to mess <path> with
	unmanaged files (see example below).
    -u	Update instead of install.
Example:
    $name -D /opt/snort2pf -L /usr/local
EOF
}

: ${DESTDIR:=/usr/local}
: ${LINKDIR:=}
: ${UPDATE:=}

while getopts 'D:hL:u' opt; do
	case $opt in
	D) DESTDIR="$OPTARG" ;;
	h) usage; exit 0 ;;
	L) LINKDIR="$OPTARG" ;;
	u) UPDATE=yes ;;
	esac
done
shift $(($OPTIND - 1))

INSTALL=/usr/bin/install
LN=/bin/ln

case `uname -s` in
DragonFly) IV=-v; LV=-v ;;
FreeBSD)   IV=-v; LV=-v ;;
NetBSD)    IV=;   LV=-v ;;
OpenBSD)   IV=;   LV=   ;;
esac

set -e

echo ">>> Installing files..."
${INSTALL} $IV -d "${DESTDIR}/sbin"
${INSTALL} -S $IV snort2pf snort2pfmon "${DESTDIR}/sbin"

${INSTALL} $IV -d "${DESTDIR}/man/man8"
${INSTALL} -S $IV -m 444 snort2pf.8 snort2pfmon.8 "${DESTDIR}/man/man8"

if [ -z "$LINKDIR" ]; then
	echo ">>> Creating symlinks..."
	trap 'echo "Maybe you should try -u."' EXIT
	[ -n "$UPDATE" ] && LN="${LN} -f"

	${INSTALL} $IV -d "${LINKDIR}/sbin"
	for f in snort2pf snort2pfmon; do
		${LN} $LV $LU -s "${DESTDIR}/sbin/$f" "${LINKDIR}/sbin/$f"
	done

	${INSTALL} $IV -d "${LINKDIR}/man/man8"
	for f in snort2pf.8 snort2pfmon.8; do
		${LN} $LV $LU -s "${DESTDIR}/man/man8/$f" "${LINKDIR}/man/man8/$f"
	done

	trap - EXIT
fi

echo
echo "Don't forget to add the following line to you pf.conf(5):"
echo "\"anchor snort2pf\""
